@@ -96,18 +96,18 @@ impl Default for ProposalState {
 /// The type of the vote threshold percentage used to resolve a vote on a Proposal
 #[repr(C)]
 #[derive(Clone, Debug, PartialEq, BorshDeserialize, BorshSerialize, BorshSchema)]
-pub enum VoteThresholdPercentageType {
+pub enum VoteThresholdPercentage {
     /// Voting threshold of Yes votes in % required to tip the vote
     /// It's the percentage of tokens out of the entire pool of governance tokens eligible to vote
     /// Note: If the threshold is below or equal to 50% then an even split of votes ex: 50:50 or 40:40 is always resolved as Defeated
-    /// In other words +1 vote tie breaker is always required to have a successful vote
-    YesVote,
+    /// In other words a '+1 vote' tie breaker is always required to have a successful vote
+    YesVote(u8),
 
     /// The minimum number of votes in % out of the entire pool of governance tokens eligible to vote
     /// which must be cast for the vote to be valid
     /// Once the quorum is achieved a simple majority (50%+1) of Yes votes is required for the vote to succeed
     /// Note: Quorum is not implemented in the current version
-    Quorum,
+    Quorum(u8),
 }
 
 /// The source of voter weights used to vote on proposals
@@ -126,6 +126,9 @@ pub enum VoteWeightSource {
 #[repr(C)]
 #[derive(Clone, Debug, PartialEq, BorshDeserialize, BorshSerialize, BorshSchema)]
 pub enum InstructionExecutionStatus {
+    /// Instruction was not executed yet
+    None,
+
     /// Instruction was executed successfully
     Success,
 
@@ -139,6 +142,10 @@ pub enum InstructionExecutionStatus {
 #[repr(C)]
 #[derive(Clone, Debug, PartialEq, BorshDeserialize, BorshSerialize, BorshSchema)]
 pub enum InstructionExecutionFlags {
+    /// No execution flags are specified
+    /// Instructions can be executed individually, in any order, as soon as they hold_up time expires
+    None,
+
     /// Instructions are executed in a specific order
     /// Note: Ordered execution is not supported in the current version
     /// The implementation requires another account type to track deleted instructions
