@@ -3,7 +3,7 @@
 use crate::{
     error::GovernanceError,
     state::{
-        enums::{GovernanceAccountType, VoteThresholdPercentageType, VoteWeightSource},
+        enums::{GovernanceAccountType, VoteThresholdPercentage, VoteWeightSource},
         realm::assert_is_valid_realm,
     },
     tools::account::{get_account_data, AccountMaxSize},
@@ -26,10 +26,7 @@ pub struct GovernanceConfig {
 
     /// The type of the vote threshold used for voting
     /// Note: In the current version only YesVote threshold is supported
-    pub vote_threshold_percentage_type: VoteThresholdPercentageType,
-
-    /// The vote threshold value of the type defined by vote_threshold_percentage_type
-    pub vote_threshold_percentage: u8,
+    pub vote_threshold_percentage: VoteThresholdPercentage,
 
     /// Minimum number of tokens a governance token owner must possess to be able to create a proposal
     pub min_tokens_to_create_proposal: u64,
@@ -61,7 +58,7 @@ pub struct Governance {
     pub config: GovernanceConfig,
 
     /// Reserved space for future versions
-    pub reserved: u64,
+    pub reserved: [u8; 8],
 
     /// Running count of proposals
     pub proposals_count: u32,
@@ -112,6 +109,25 @@ pub fn get_governance_data(
     get_account_data::<Governance>(governance_info, program_id)
 }
 
+/// Deserializes governance account data and validates it's consistent with the given config
+pub fn get_governance_data_for_config(
+    program_id: &Pubkey,
+    governance_info: &AccountInfo,
+    config: &GovernanceConfig,
+) -> Result<Governance, ProgramError> {
+    let governance_data = get_governance_data(program_id, governance_info)?;
+
+    if governance_data.config.realm != config.realm {
+        return Err(GovernanceError::InvalidConfigRealmForGovernance.into());
+    }
+
+    if governance_data.config.governed_account != config.governed_account {
+        return Err(GovernanceError::InvalidConfigGovernedAccountForGovernance.into());
+    }
+
+    Ok(governance_data)
+}
+
 /// Returns ProgramGovernance PDA seeds
 pub fn get_program_governance_address_seeds<'a>(
     realm: &'a Pubkey,
@@ -217,19 +233,20 @@ pub fn assert_is_valid_governance_config(
     realm_info: &AccountInfo,
 ) -> Result<(), ProgramError> {
     if realm_info.key != &governance_config.realm {
-        return Err(GovernanceError::InvalidGovernanceConfig.into());
+        return Err(GovernanceError::InvalidConfigRealmForGovernance.into());
     }
 
     assert_is_valid_realm(program_id, realm_info)?;
 
-    if governance_config.vote_threshold_percentage < 1
-        || governance_config.vote_threshold_percentage > 100
-    {
-        return Err(GovernanceError::InvalidGovernanceConfig.into());
-    }
-
-    if governance_config.vote_threshold_percentage_type != VoteThresholdPercentageType::YesVote {
-        return Err(GovernanceError::VoteThresholdPercentageTypeNotSupported.into());
+    match governance_config.vote_threshold_percentage {
+        VoteThresholdPercentage::YesVote(yes_vote_threshold_percentage) => {
+            if !(1..=100).contains(&yes_vote_threshold_percentage) {
+                return Err(GovernanceError::InvalidVoteThresholdPercentage.into());
+            }
+        }
+        _ => {
+            return Err(GovernanceError::VoteThresholdPercentageTypeNotSupported.into());
+        }
     }
 
     if governance_config.vote_weight_source != VoteWeightSource::Deposit {
